"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@stylable/core");
const vscode_languageserver_types_1 = require("vscode-languageserver-types");
function createDiagnosis(content, version, filePath, stylable, cssService) {
    if (!filePath.endsWith('.st.css')) {
        return [];
    }
    const docPostCSSRoot = core_1.safeParse(content, { from: filePath });
    if (docPostCSSRoot.source) {
        const { input } = docPostCSSRoot.source;
        // postcss runs path.resolve, which messes up in-memory fs implementation on windows
        Object.defineProperty(input, 'from', { value: filePath });
        input.file = filePath;
    }
    const meta = core_1.process(docPostCSSRoot);
    stylable.fileProcessor.add(filePath, meta);
    try {
        stylable.transform(meta);
    }
    catch {
        /**/
    }
    const cleanDoc = cssService.createSanitizedDocument(meta.rawAst, filePath, version);
    return meta.diagnostics.reports
        .concat(meta.transformDiagnostics ? meta.transformDiagnostics.reports : [])
        .map(reportToDiagnostic)
        .concat(cssService.getDiagnostics(cleanDoc));
    // stylable diagnostic to protocol diagnostic
    function reportToDiagnostic(report) {
        const severity = report.type === 'error' ? 1 : 2;
        const range = createRange(report);
        return vscode_languageserver_types_1.Diagnostic.create(range, report.message, severity, undefined, 'stylable');
    }
}
exports.createDiagnosis = createDiagnosis;
function createRange(report) {
    const source = report.node.source;
    const start = { line: 0, character: 0 };
    const end = { line: 0, character: 0 };
    if (report.options.word && source) {
        const lines = source.input.css.split('\n');
        const searchStart = source.start.line - 1;
        const searchEnd = source.end.line - 1;
        for (let i = searchStart; i <= searchEnd; ++i) {
            const wordIndex = lines[i].indexOf(report.options.word);
            if (~wordIndex) {
                start.line = i;
                start.character = wordIndex;
                end.line = i;
                end.character = wordIndex + report.options.word.length;
                break;
            }
        }
    }
    else if (source) {
        start.line = source.start.line - 1;
        start.character = source.start.column - 1;
        end.line = source.end.line - 1;
        end.character = source.end.column;
    }
    return vscode_languageserver_types_1.Range.create(start, end);
}
exports.createRange = createRange;
//# sourceMappingURL=diagnosis.js.map