import { IFileSystem } from '@file-services/types';
import { Stylable } from '@stylable/core';
import { ColorPresentationParams } from 'vscode-languageserver-protocol';
import { TextDocument } from 'vscode-languageserver-textdocument';
import { Color, ColorInformation, ColorPresentation, CompletionItem, Diagnostic, Hover, Location, ParameterInformation, Position, SignatureHelp, WorkspaceEdit } from 'vscode-languageserver-types';
import { ProviderPosition } from './completion-providers';
import { Completion } from './completion-types';
import { CssService } from './css-service';
import { Provider } from './provider';
import { ExtendedTsLanguageService } from './types';
interface Config {
    fs: IFileSystem;
    stylable: Stylable;
}
export declare class StylableLanguageService {
    cssService: CssService;
    protected fs: IFileSystem;
    protected provider: Provider;
    protected stylable: Stylable;
    protected tsLanguageService: ExtendedTsLanguageService;
    constructor({ fs, stylable }: Config);
    getStylable(): Stylable;
    getFs(): IFileSystem;
    onCompletion(filePath: string, offset: number): CompletionItem[];
    onDefinition(filePath: string, offset: number): Location[];
    onHover(filePath: string, offset: number): Hover | null;
    onReferences(filePath: string, offset: number): Location[];
    onDocumentColor(filePath: string): ColorInformation[];
    onColorPresentation(filePath: string, offset: {
        start: number;
        end: number;
    }, color: Color): ColorPresentation[];
    onRenameRequest(filePath: string, offset: number, newName: string): WorkspaceEdit;
    onSignatureHelp(filePath: string, offset: number): SignatureHelp | null;
    onDocumentFormatting(): null;
    provideCompletionItemsFromSrc(src: string, pos: Position, fileName: string): Completion[];
    getCompletions(document: TextDocument, filePath: string, position: Position): CompletionItem[];
    getDefinitionLocation(src: string, position: ProviderPosition, filePath: string): Location[];
    getSignatureHelp(src: string, pos: Position, filePath: string, paramInfo: typeof ParameterInformation): SignatureHelp | null;
    getRefs(filePath: string, position: ProviderPosition): Location[];
    resolveDocumentColors(document: TextDocument): ColorInformation[];
    getColorPresentation(document: TextDocument, params: ColorPresentationParams): ColorPresentation[];
    diagnose(filePath: string): Diagnostic[];
    private readStylableFile;
}
export {};
//# sourceMappingURL=service.d.ts.map